@@ -75,6 +75,7 @@ PDL_Err PDL_CustomPauseUiEnable(PDL_bool enable);
 PDL_Err PDL_EnableLocationTracking(PDL_bool activate);
 PDL_Err PDL_GesturesEnable(PDL_bool enable);
 PDL_Err PDL_GetCallingPath(char *buffer, int bufferLen);
+PDL_Err PDL_GetDataFilePath(const char *dataFile, char *buffer, int bufferLen);
 PDL_Err PDL_GetDeviceName(char *buffer, int bufferLen);
 const char *PDL_GetError(void);
 const char *PDL_GetHardware(void);
@@ -84,9 +85,10 @@ PDL_Err PDL_GetNetInfo(const char *interfaceName, PDL_NetInfo * interfaceInfo);
 PDL_Err PDL_GetOSVersion(PDL_OSVersion *version);
 PDL_Err PDL_GetScreenMetrics(PDL_ScreenMetrics* metrics);
 PDL_Err PDL_GetUniqueID(char *buffer, int bufferLen);
-PDL_bool PDL_IsPlugin();
+PDL_bool PDL_IsPlugin(void);
 PDL_Err PDL_Init(unsigned int flags);
 PDL_Err PDL_LaunchBrowser(const char* url);
+PDL_Err PDL_Minimize(void);
 PDL_Err PDL_NotifyMusicPlaying(PDL_bool musicPlaying);
 PDL_Err PDL_ScreenTimeoutEnable(PDL_bool enable);
 PDL_Err PDL_SetFirewallPortStatus(int port, PDL_bool open);
