@@ -33,16 +33,16 @@
 
 #define SCREEN_TIMEOUT_TIME 45
 
-#define BT_SERVICE				"org.bluez"
-#define BT_DEF_ADAPTER_IF		"org.bluez.Manager"
-#define BT_DEF_ADAPTER_PATH		"/"
-#define BT_DEF_ADAPTER_METHOD	"DefaultAdapter"
-#define BT_ADAPTER_IF			"org.bluez.Adapter"
-#define BT_ADAPTER_GETPROPS		"GetProperties"
+#define BT_SERVICE              "org.bluez"
+#define BT_DEF_ADAPTER_IF       "org.bluez.Manager"
+#define BT_DEF_ADAPTER_PATH     "/"
+#define BT_DEF_ADAPTER_METHOD   "DefaultAdapter"
+#define BT_ADAPTER_IF           "org.bluez.Adapter"
+#define BT_ADAPTER_GETPROPS     "GetProperties"
 
-#define UNIQUE_ID_FILE			"/home/user/.preenv-uid"
-#define RANDOM_SRC_FILE			"/dev/random"
-#define UNIQUE_ID_RND_SIZE		24
+#define TASKNAV_IF              "com.nokia.hildon_desktop"
+#define TASKNAV_PATH            "/"
+#define TASKNAV_SIGNAL          "exit_app_view"
 
 static gboolean basic_init_done = FALSE;
 static GMainContext *main_context = NULL;
@@ -434,6 +434,37 @@ PDL_Err PDL_GetCallingPath(char *buffer, int bufferLen)
 	return copy_to_user("./", buffer, bufferLen);
 }
 
+PDL_Err PDL_GetDataFilePath(const char *dataFile, char *buffer, int bufferLen)
+{
+	CHECK_IMPLICIT_PDL_INIT();
+	TRACE("%s of %s", __func__, dataFile);
+
+	/* We allocate a big enough buffer ourselves; even if the buffer passed
+     * is too small, we don't want to mkdir any random directories around. */
+	char path[strlen(DATA_FILE_PATH) + strlen(dataFile) + 1];
+	int res;
+
+	strcpy(path, DATA_FILE_PATH);
+	res = mkdir(path, DATA_FILE_PERM);
+	if (res == -1 && errno != EEXIST) goto fail_mkdir;
+
+	/* Use service name to give each application a private path. */
+	strcat(path, "/");
+	strcat(path, servicename);
+	res = mkdir(path, DATA_FILE_PERM);
+	if (res == -1 && errno != EEXIST) goto fail_mkdir;
+
+	strcat(path, "/");
+	strcat(path, dataFile);
+
+	return copy_to_user(path, buffer, bufferLen);
+
+fail_mkdir:
+	WARN("Couldn't create the data file directory (%s)", path);
+	set_error("Couldn't create the data file directory");
+	return PDL_SYSTEMERROR_FILE;
+}
+
 PDL_Err PDL_GetDeviceName(char *buffer, int bufferLen)
 {
 	CHECK_IMPLICIT_PDL_INIT();
@@ -622,7 +653,7 @@ err_return:
 	return copy_to_user("0000", buffer, bufferLen);
 }
 
-PDL_bool PDL_IsPlugin()
+PDL_bool PDL_IsPlugin(void)
 {
 	/* No support for hybrid applications. */
 	return PDL_FALSE;
@@ -643,6 +674,37 @@ PDL_Err PDL_LaunchBrowser(const char* url)
 	}
 }
 
+PDL_Err PDL_Minimize(void)
+{
+	CHECK_IMPLICIT_PDL_INIT();
+	/* TODO: I did not find a way to do this with GLib-DBus
+	 *  WITHOUT lots of gobject boilerplate. */
+	DBusConnection *conn;
+	DBusMessage *msg;
+	DBusError error;
+	dbus_error_init(&error);
+
+	conn = dbus_bus_get(DBUS_BUS_SESSION, &error);
+	if (dbus_error_is_set(&error)) {
+		WARN("Failed to get session bus: %s", error.message);
+		set_error("Failed to get session bus: %s", error.message);
+		dbus_error_free(&error);
+		return PDL_EOTHER;
+	}
+
+	msg = dbus_message_new_signal(TASKNAV_PATH, TASKNAV_IF, TASKNAV_SIGNAL);
+	if (!msg) {
+		WARN("Out of memory");
+		set_error("Out of memory");
+		return PDL_EOTHER;
+	}
+
+	dbus_connection_send(conn, msg, NULL);
+	dbus_message_unref(msg);
+
+	return PDL_NOERROR;
+}
+
 PDL_Err PDL_NotifyMusicPlaying(PDL_bool musicPlaying)
 {
 	TRACE("Playing music notification: %s", musicPlaying ? "Playing" : "No music");
