@@ -53,6 +53,9 @@ void PDL_NotifyFocus(SDL_bool focus);
 
 void X11_Init();
 void X11_SetDoNotDisturb(SDL_bool set);
+
+void TaskBtn_Press();
+void TaskBtn_Release();
 #pragma GCC visibility pop
 
 #endif
