@@ -24,6 +24,8 @@ static SDL_Surface *v_screen = NULL;
 static SDL_bool app_active = SDL_FALSE;
 static SDL_EventFilter app_filter = NULL;
 
+static SDL_bool taskbtn_pressed = SDL_FALSE;
+
 static int gles_init()
 {
 	if (!gles_inited) {
@@ -135,6 +137,7 @@ void SDLPRE_PushEvent(SDL_Event *event) {
 static int filter_active_event(const SDL_ActiveEvent *event) {
 	SDL_Event fakeevent;
 	SDL_ActiveEvent *fake = &fakeevent.active;
+
 	fake->type = SDL_ACTIVEEVENT;
 	fake->gain = event->gain;
 	fake->state = 0;
@@ -153,11 +156,20 @@ static int filter_active_event(const SDL_ActiveEvent *event) {
 static int filter_mouse_motion(const SDL_MouseMotionEvent *event) {
 	SDL_Event fakeevent;
 	SDL_MouseMotionEvent *fake = &fakeevent.motion;
-	*fake = *event;
 	struct point p = { event->x, event->y };
 	struct point prel = { event->xrel, event->yrel };
+
+	if (event->x < TASKNAV_BTN_WIDTH && event->y < TASKNAV_BTN_HEIGHT) {
+		/* Cursor still inside button area: OK */
+	} else if (taskbtn_pressed) {
+		/* Cursor exited button area */
+		TaskBtn_Release();
+		taskbtn_pressed = SDL_FALSE;
+	}
+
 	p_unscale(&p);
 	p_unscale(&prel);
+	*fake = *event;
 	fake->x = p.x;
 	fake->y = p.y;
 	fake->xrel = prel.x;
@@ -170,9 +182,20 @@ static int filter_mouse_motion(const SDL_MouseMotionEvent *event) {
 static int filter_mouse_button(const SDL_MouseButtonEvent *event) {
 	SDL_Event fakeevent;
 	SDL_MouseButtonEvent *fake = &fakeevent.button;
-	*fake = *event;
 	struct point p = { event->x, event->y };
+
+	if (event->x < TASKNAV_BTN_WIDTH && event->y < TASKNAV_BTN_HEIGHT) {
+		if (event->type == SDL_MOUSEBUTTONUP && taskbtn_pressed) {
+			TaskBtn_Release();
+			taskbtn_pressed = SDL_FALSE;
+		} else if (event->type == SDL_MOUSEBUTTONDOWN && !taskbtn_pressed) {
+			TaskBtn_Press();
+			taskbtn_pressed = SDL_TRUE;
+		}
+	}
+
 	p_unscale(&p);
+	*fake = *event;
 	fake->x = p.x;
 	fake->y = p.y;
 
@@ -570,4 +593,3 @@ void glScissor(GLint x, GLint y, GLsizei width, GLsizei height)
 	SUPER(b.x, b.y, b.w, b.h);
 }
 
-
